<?php
/**
 * Admin file of Module
 *
 * Manage all settings and actions of admin
 *
 * @package  my-account-page-editor
 * @version  1.1.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

if ( ! class_exists( 'KA_MyAcc_Admin' ) ) {
	/**
	 * Admin class of module.
	 */
	class KA_MyAcc_Admin {
		/**
		 * Constructor of class.
		 */
		public function __construct() {
			// Enqueue Admin CSS JS.
			add_action( 'admin_enqueue_scripts', array( $this, 'kamy_acc_admin_enqueue_scripts' ) );

			// add menus & sub menu.
			add_action( 'admin_menu', array( $this, 'kamy_acc_custom_menu_admin' ) );
			// create meta box.
			add_action( 'add_meta_boxes', array( $this, 'kamy_acc_meta_box' ) );
			// Save MetaBox Values.
			add_action( 'save_post_kamy_acc', array( $this, 'kamy_acc_save_metabox_values' ) );
			// Settings Fields.
			add_action( 'admin_init', array( $this, 'kamy_acc_settings_fields' ) );
		}

		/**
		 * Enqueue scripts for admin.
		 */
		public function kamy_acc_admin_enqueue_scripts() {

			$screen = get_current_screen();

			if ( 'kamy_acc' === $screen->id ||'kamy_acc_page_customize-my-account-page-layout' == $screen->id  ) {

				// Upload Font-Awesome 4.

				wp_enqueue_script( 'kamy_acc_admin', plugins_url( '../assets/js/kamy_acc_admin.js', __FILE__ ), array( 'jquery' ), '1.0', false );

				wp_enqueue_style( 'kamy_acc_admin', plugins_url( '../assets/css/kamy_acc_admin.css', __FILE__ ), array(), '1.0' );

				// Enqueue Select2 JS CSS.
				wp_enqueue_style( 'select2', plugins_url( '../assets/css/select2.css', __FILE__ ), array(), '1.0' );

				wp_enqueue_script( 'select2', plugins_url( '../assets/js/select2.js', __FILE__ ), false, '1.0', array( 'jquery' ), '1.0', false );
				wp_enqueue_style( 'wp-color-picker' );

				// Enqueue WP_MEDIA.
				wp_enqueue_media();

				wp_dequeue_style( 'font-awesome' );

				wp_enqueue_style( 'Font_Awesome', 'https://maxcdn.bootstrapcdn.com/font-awesome/latest/css/font-awesome.min.css', false, '1.0' );

				wp_enqueue_style( 'jquery_ui', '//code.jquery.com/ui/1.12.1/themes/base/jquery-ui.css', array(), '1.12.1' );

				wp_enqueue_script( 'jquery_ui', 'https://code.jquery.com/ui/1.12.1/jquery-ui.js', array( 'jquery' ), '1.12.1', false );

				wp_localize_script(
					'kamy_acc_admin',
					'kamy_data',
					array(
						'templateImageUrl'  => esc_url( ADDMY_ACC_URL . 'assets/img/vertical-right-column.png' ),
						'templateImageUrl2' => esc_url( ADDMY_ACC_URL . 'assets/img/vertical-left-column.png' ),
						'templateImageUrl3' => esc_url( ADDMY_ACC_URL . 'assets/img/vertical-middle-chart.png' ),
					)
					);
			}
		}

		/**
		 * Add menu in admin bar.
		 */
		public function kamy_acc_custom_menu_admin() {

			add_submenu_page(
				'edit.php?post_type=kamy_acc', // parent_slug.
				esc_html__( 'My Account Page Editor', 'ka-my-acc' ), // page title.
				esc_html__( 'Settings', 'ka-my-acc' ), // menu title.
				'manage_options', // capability.
				'customize-my-account-page-layout', // slug.
				array( $this, 'kamy_acc_settings_callback' ), // callback function.
				10 // position.
			);
		}

		/**
		 * Add meta box in custom post type.
		 */
		public function kamy_acc_meta_box() {

			add_meta_box(
				'kamy_acc_metabox', // id.
				esc_html__( 'Endpoint', 'ka-my-acc' ), // title which will be shown at top of metabox.
				array( $this, 'kamy_acc_metabox_cb' ), // callback function name.
				'kamy_acc', // The screen or screens on which to show the box (such as a post type, 'link', or 'comment').
				'normal', // The context within the screen where the boxes should display.
				'high' // The priority within the context where the boxes should show ('high', 'low').
			);
		}

		/**
		 * Add fields in custom meta box.
		 */
		public function kamy_acc_metabox_cb() {

			global $post;

			wp_nonce_field( 'kamy_acc_fields_nonce', 'kamy_acc_fields_nonce' );

			$kamy_acc_slug = get_post_meta( intval( $post->ID ), 'kamy_acc_slug_fld', true );

			$kamy_acc_icon = get_post_meta( intval( $post->ID ), 'kamy_acc_icon_fld', true );

			$kamy_acc_user_role = get_post_meta( intval( $post->ID ), 'kamy_acc_user_role', true );

			$kamy_acc_eptype = get_post_meta( intval( $post->ID ), 'kamy_acc_endpType_fld', true );

			$kamy_acc_cust_cont = get_post_meta( intval( $post->ID ), 'kamy_acc_custom_cont_fld', true );

			$kamy_acc_link = get_post_meta( intval( $post->ID ), 'kamy_acc_link_fld', true );

			$kamy_acc_page = get_post_meta( intval( $post->ID ), 'kamy_acc_page_fld', true );

			$kamy_acc_menu_title = get_post_meta( intval( $post->ID ), 'kamy_acc_menu_title', true );

			if ( empty( $kamy_acc_slug ) ) {
				$kamy_acc_slug = 'kamc_slug_' . $post->ID;
			}

			if ( empty( $kamy_acc_grp_mem ) ) {

				$kamy_acc_grp_mem = array();

			}

			?>
			<div class="new-endpoint-form">

				<table class="addify-table-optoin">

					<tr class="addify-option-field">

						<th>

							<div class="option-head">

								<h3>

									<?php esc_html_e( 'Menu Title', 'ka-my-acc' ); ?>

								</h3>

							</div>	

						</th>

						<td>

							<input type="text" class="kamy_acc_input width-60" name="kamy_acc_menu_title" id="kamy_acc_slug_fld" value="<?php echo esc_attr( $kamy_acc_menu_title ) ? esc_attr( $kamy_acc_menu_title ) : ''; ?>" />
							<br>
							<p><?php esc_html_e( 'Assign a title to endpoint to show in menu of my-account navigation bar. If you leave the menu title empty the end point title will be used as menu title.', 'ka-my-acc' ); ?></p>
						</td>

					</tr>

					<tr class="addify-option-field">

						<th>

							<div class="option-head">

								<h3>

									<?php esc_html_e( 'Menu Slug', 'ka-my-acc' ); ?>

								</h3>

							</div>	

						</th>

						<td>

							<input type="text" class="kamy_acc_input width-60" name="kamy_acc_slug_fld" id="kamy_acc_slug_fld" value="<?php echo esc_attr( $kamy_acc_slug ) ? esc_attr( $kamy_acc_slug ) : ''; ?>" />
							<br>
							<p><?php esc_html_e( 'Assign a unique slug to each endpoint.', 'ka-my-acc' ); ?></p>
						</td>

					</tr>

					<tr class="addify-option-field">

						<th>

							<div class="option-head">

								<h3>

									<?php esc_html_e( 'Icon', 'ka-my-acc' ); ?>

								</h3>

							</div>

						</th>

						<td>

							<select name="kamy_acc_icon_fld" class="width-60" id="kamy_acc_icon_fld" >

								<option value=''><?php echo esc_html__( 'Choose Icon', 'ka-my-acc' ); ?></option>

								<?php
								include_once 'ka-icon-options.php';
								?>

							</select>
							<p> <?php echo esc_html__('The icons preview may not work for devices in dropdown. Please select any to see preview. Most of these fonts are available.', 'ka-my-acc'); ?> 
							<a href="https://fontawesome.com/icons?d=gallery&m=free"><?php echo esc_html__('here', 'ka-my-acc'); ?></a>
						</td>

					</tr>
					<tr class="addify-option-field">
						<th>
							<div class="option-head">
								<h3><?php esc_html_e( 'User Role', 'ka-my-acc' ); ?></h3>
							</div>
						</th>
						<td>
							<?php
							if ( empty( $kamy_acc_user_role ) ) {
								$kamy_acc_user_role = array();
							}
							global $wp_roles;
							?>
							<select name="kamy_acc_user_role[]" id="kamy_acc_user_role" multiple>
								<?php foreach ( $wp_roles->get_names() as $key => $name ) : ?>
									<option value="<?php echo esc_attr( $key ); ?>" <?php selected( in_array( $key, $kamy_acc_user_role, true ) ); ?>><?php echo esc_html( $name ); ?></option>
								<?php endforeach; ?>
								<option value="guest" <?php selected( in_array( 'guest', $kamy_acc_user_role, true ) ); ?>><?php esc_html_e( 'Guest', 'ka-my-acc' ); ?></option>
							</select>
							<p class="description"><?php esc_html_e( 'Leave empty to apply on all user roles.', 'ka-my-acc' ); ?></p>
						</td>
					</tr>





							<tr class="addify-option-field">

								<th>

									<div class="option-head">

										<h3>

											<?php esc_html_e( 'Endpoint Type', 'ka-my-acc' ); ?>

										</h3>

									</div>

								</th>

								<td>

									<select name="kamy_acc_endpType_fld" class="width-60" id="kamy_acc_endpType_fld">
										<option value="sendpoint" 
										<?php
										if ( 'sendpoint' === esc_attr( $kamy_acc_eptype ) ) {
											echo 'selected'; }
										?>
											>
											<?php esc_html_e( 'Single', 'ka-my-acc' ); ?>
										</option>

										<option value="pendpoint" 
										<?php
										if ( 'pendpoint' === esc_attr( $kamy_acc_eptype ) ) {
											echo 'selected'; }
										?>
											>
											<?php esc_html_e( 'Page', 'ka-my-acc' ); ?>
										</option>
										<option value="lendpoint" 
										<?php
										if ( 'lendpoint' === esc_attr( $kamy_acc_eptype ) ) {
											echo 'selected'; }
										?>
											>
											<?php esc_html_e( 'Link', 'ka-my-acc' ); ?>

										</option>group_endpoint

										<option value="group_endpoint" 
										<?php
										if ( 'group_endpoint' === esc_attr( $kamy_acc_eptype ) ) {
											echo 'selected'; }
										?>
											>
											<?php esc_html_e( 'Group', 'ka-my-acc' ); ?>
										</option>
									</select>
								</td>
							</tr>
							<tr class="addify-option-field kamy_acc_group_child_filed">
								<th>
									<div class="option-head">
										<h3>
											<?php esc_html_e( 'Select Custom Endpoints', 'ka-my-acc' ); ?>
										</h3>
									</div>
								</th>
								<td>
									<select multiple='multiple' class="kamy_acc_group_child width-60" name="kamy_acc_group_child[]" id="kamy_acc_group_child">
										<?php
										$args           = array(
											'numberposts' => -1,
											'post_type'   => 'kamy_acc',
										);
										$selected_child = (array) json_decode( get_post_meta( $post->ID, 'kamy_acc_group_child', true ) );

										$all_end_points = get_posts( $args );

										foreach ( $all_end_points as $endpoint ) {
											$endpoint_id = $endpoint->ID;

											$end_point_type = get_post_meta( $endpoint_id, 'kamy_acc_endpType_fld', true );

											if ( 'group_endpoint' === $end_point_type ) {
												continue;
											}
											?>
											<option  value="<?php echo esc_attr( $endpoint_id ); ?>" 
												<?php
												if ( in_array( (string) $endpoint_id, $selected_child, true ) ) {
													echo 'selected';
												}
												?>
												>
												<?php echo esc_attr( $endpoint->post_title ); ?>
											</option>
											<?php
										}
										?>
									</select>
								</td>
							</tr>
							<tr class="addify-option-field kamy_acc_group_child_filed">
								<th>
									<div class="option-head">
										<h3>
											<?php esc_html_e( 'Select Default Endpoints', 'ka-my-acc' ); ?>
										</h3>
									</div>
								</th>
								<td>
									<?php

									$kamy_acc_group_default_filed = get_post_meta( intval( $post->ID ), 'kamy_acc_group_default_filed', true );

									$kamy_acc_group_default_filed = (array) json_decode( $kamy_acc_group_default_filed );

									$items = array(
										'dashboard'       => __( 'Dashboard', 'woocommerce' ),
										'orders'          => __( 'Orders', 'woocommerce' ),
										'downloads'       => __( 'Downloads', 'woocommerce' ),
										'edit-address'    => __( 'Addresses', 'woocommerce' ),
										'payment-methods' => __( 'Payment methods', 'woocommerce' ),
										'edit-account'    => __( 'Account details', 'woocommerce' ),
										'customer-logout' => __( 'Logout', 'woocommerce' ),
									);

									foreach ( $items as $key => $value ) {
										?>
										<input type="checkbox" name="kamy_acc_group_default_filed[]" value="<?php echo esc_attr( $key ); ?>" 
										<?php
										if ( in_array( esc_attr( $key ), $kamy_acc_group_default_filed, true ) ) {
											echo 'checked';
										}
										?>
										> 
										<?php echo esc_attr( $value ); ?> 
										<br>
										<?php
									}
									?>
								</td>
							</tr>
							<tr class="addify-option-field content_fld">
								<th>
									<div class="option-head">
										<h3>
											<?php esc_html_e( 'Custom Content', 'ka-my-acc' ); ?>
										</h3>
									</div>
								</th>
								<td>
									<?php
									$settings = array(
										'wpautop'          => false,
										'media_buttons'    => true,
										'textarea_name'    => 'kamy_acc_custom_cont_fld',
										'tinymce'          => true,
										'textarea_rows'    => 15,
										'quicktags'        => true,
										'drag_drop_upload' => true,
									);
									wp_editor( $kamy_acc_cust_cont, 'kamy_acc_custom_cont_fld', $settings );
									?>
								</td>

							</tr>

							<tr class="addify-option-field link_fld">
								<th>
									<div class="option-head">
										<h3>
											<?php esc_html_e( 'Link', 'ka-my-acc' ); ?>
										</h3>	
									</div>
								</th>
								<td>
									<input type="text" class="kamy_acc_input width-60" name="kamy_acc_link_fld" id="kamy_acc_link_fld" value="<?php echo esc_url( $kamy_acc_link ); ?>">
								</td>
							</tr>
							<tr class="addify-option-field page_fld">
								<th>
									<div class="option-head">
										<h3>
											<?php esc_html_e( 'Select Page', 'ka-my-acc' ); ?>
										</h3>
									</div>	
								</th>
								<td>
									<?php
									$pages = get_pages();
									?>
									<select name="kamy_acc_page_fld" class="width-60" id="kamy_acc_page_fld" >
										<option value=""> Select Page</option>
										<?php
										foreach ( (array) $pages as $page ) {
											?>
											<option value="<?php echo esc_attr( $page->ID ); ?>" 
												<?php
												if ( $page->ID === (int) $kamy_acc_page ) {
													echo 'selected';
												}
												?>
												> 
												<?php echo esc_attr( $page->post_title ); ?> </option>
												<?php
										}
										?>
										</select>

									</td>

								</tr>						

							</table>

						</div>

						<?php
		}

		/**
		 * Add admin settings.
		 */
		public function kamy_acc_settings_callback() {

			global $active_tab;

			

			if ( isset( $_GET['tab'] ) ) {

				$active_tab = sanitize_text_field( wp_unslash( $_GET['tab'] ) );

			} else {

				$active_tab = 'endpoints_settings';

			}

			?>

			<div class="wrap">

				<div id="icon-tools" class="icon32"></div>

				<h2> <?php echo esc_html__( 'Endpoints Settings', 'ka-my-acc' ); ?></h2>

				<?php settings_errors(); ?>

				<h2 class="nav-tab-wrapper">

					<a href="?post_type=kamy_acc&page=customize-my-account-page-layout&tab=endpoints_settings" class="nav-tab  <?php echo esc_attr( $active_tab ) === 'endpoints_settings' ? ' nav-tab-active' : ''; ?>" > <?php esc_html_e( 'Endpoints Settings', 'ka-my-acc' ); ?> </a>
					<a href="?post_type=kamy_acc&page=customize-my-account-page-layout&tab=custom_sorting" class="nav-tab  <?php echo esc_attr( $active_tab ) === 'custom_sorting' ? ' nav-tab-active' : ''; ?>" > <?php esc_html_e( 'Endpoints Sorting', 'ka-my-acc' ); ?> </a>
					<a href="?post_type=kamy_acc&page=customize-my-account-page-layout&tab=custom_links" class="nav-tab  <?php echo esc_attr( $active_tab ) === 'custom_links' ? ' nav-tab-active' : ''; ?>" > <?php esc_html_e( 'Custom Links', 'ka-my-acc' ); ?> </a>
					<a href="?post_type=kamy_acc&page=customize-my-account-page-layout&tab=dashboard_setting" class="nav-tab  <?php echo esc_attr( $active_tab ) === 'dashboard_setting' ? ' nav-tab-active' : ''; ?>" > <?php esc_html_e( 'Dashboard Setting', 'ka-my-acc' ); ?> </a>

				</h2>
				<?php
				$sections = array(
					'general'  => __( 'General', 'woocommerce' ),
					'template' => __( 'Template', 'woocommerce' ),
					'design'    => __( 'Design', 'woocommerce' ),
				);

				$current_tab     = $active_tab;
				$current_section = isset( $_GET['section'] ) ? sanitize_text_field( wp_unslash( $_GET['section'] ) ) : 'general';

				if ( 'dashboard_setting' ===  $current_tab) {
					echo '<ul class="subsubsub">';
					$sectionKeys = array_keys($sections);
					foreach ( $sections as $id => $value ) {
						$section_nonce = wp_create_nonce( 'section_nonce_' . $id );
						$class         = ( sanitize_title( $id ) === $current_section ) ? 'current' : '';
						echo '<li><a id="tab-' . esc_attr( sanitize_title( $id ) ) . '" href="' . esc_url( add_query_arg( array(
							'post_type' => 'kamy_acc',
							'page'      => 'customize-my-account-page-layout',
							'tab'       => 'dashboard_setting',
							'section'   => sanitize_title( $id ),
						), admin_url( 'edit.php' ) ) ) . '" class="' . esc_attr( $class ) . '">' . esc_html( $value ) . '</a></li>';
						// Check if it's not the last section before adding the divider
						if ( end ( $sectionKeys ) !== $id ) {
							echo ' | ';
						}
					}
					echo '</ul><br class="clear" />';
				}
				?>
				<form method="post" action="options.php" id="save_options_form">
					<?php
					if ( isset( $active_tab ) ) {
						if ( 'endpoints_settings' === $active_tab ) {
							settings_fields( 'kamy_acc_settings' );
							do_settings_sections( 'kamy_acc_settings_page' );
						} elseif ( 'custom_sorting' === $active_tab ) {
							settings_fields( 'kamy_acc_pro_sort_enpoints' );
							do_settings_sections( 'kamy_acc_pro_sort_enpoints_section' );
							include_once ADDMY_ACC_PLUGIN_DIR . 'admin/templates/sort-endpoints.php';
						} elseif ( 'custom_links' === $active_tab ) {
							settings_fields( 'kamy_account_links_settings' );
							do_settings_sections( 'kamy_account_links_page' );
						} elseif ( 'dashboard_setting' === $active_tab ) {
							if ( isset( $current_section ) ) {
								if ( 'general' === $current_section ) {
									settings_fields( 'kamy_dashboard_setting' );
									do_settings_sections( 'kamy_dashboard_setting_page' );
								} elseif ( 'template' === $current_section ) {
									settings_fields( 'kamy_template_setting' );
									do_settings_sections( 'kamy_template_setting_page' );
								} elseif ( 'design' === $current_section ) {
									settings_fields( 'kamy_design_setting' );
									do_settings_sections( 'kamy_design_setting_page' );
								}
							}
						}
					}
					submit_button( esc_html__( 'Save Settings', 'ka-my-acc' ), 'primary', 'kamy_acc_save_settings_btn' );
					wp_nonce_field( 'kamy_acc_fields_nonce', 'kamy_acc_fields_nonce' );
					?>

				</form>

			</div>

			<?php
		}

		/**
		 * Add admin settings fields.
		 */
		public function kamy_acc_settings_fields() {

			include_once ADDMY_ACC_PLUGIN_DIR . 'admin/settings/general-settings.php';
			include_once ADDMY_ACC_PLUGIN_DIR . 'admin/settings/sorting.php';
			include_once ADDMY_ACC_PLUGIN_DIR . 'admin/settings/dashboard-general.php';
			include_once ADDMY_ACC_PLUGIN_DIR . 'admin/settings/template-setting.php';
			include_once ADDMY_ACC_PLUGIN_DIR . 'admin/settings/design.php';
			include_once ADDMY_ACC_PLUGIN_DIR . 'admin/settings/accounts-links.php';
		}

		/**
		 * Add admin settings fields.
		 *
		 * @param int $post_id Post id.
		 */
		public function kamy_acc_save_metabox_values( $post_id ) {

			// return if we're doing an auto save
			if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) {
				return;
			}

			if ( get_post_status( $post_id ) === 'auto-draft' || get_post_status( $post_id ) === 'trash' ) {
				return;
			}

			// If our nonce isn't there, or we can't verify it, return
			if ( !isset( $_POST['kamy_acc_fields_nonce'] ) ) {
				return;
			}

			if ( !wp_verify_nonce( sanitize_text_field( $_POST['kamy_acc_fields_nonce'] ), 'kamy_acc_fields_nonce' ) ) {
				return;
			}

			// If our current user can't edit this post, return
			if ( !current_user_can( 'edit_posts' ) ) {
				return;
			}



			if ( isset( $_POST['kamy_acc_slug_fld'] ) ) {

				update_post_meta( $post_id, 'kamy_acc_slug_fld', sanitize_meta( '', wp_unslash( $_POST['kamy_acc_slug_fld'] ), '' ) );

			}

			if ( isset( $_POST['kamy_acc_icon_fld'] ) ) {

				update_post_meta( $post_id, 'kamy_acc_icon_fld', sanitize_meta( '', wp_unslash( $_POST['kamy_acc_icon_fld'] ), '' ) );

			}

			if ( isset( $_POST['kamy_acc_user_role'] ) ) {

				update_post_meta( $post_id, 'kamy_acc_user_role', sanitize_meta( '', wp_unslash( $_POST['kamy_acc_user_role'] ), '' ) );

			} else {

				update_post_meta( $post_id, 'kamy_acc_user_role', array() );
			}

			if ( isset( $_POST['kamy_acc_endpType_fld'] ) ) {
				update_post_meta( $post_id, 'kamy_acc_endpType_fld', sanitize_meta( '', wp_unslash( $_POST['kamy_acc_endpType_fld'] ), '' ) );
			}

			if ( isset( $_POST['kamy_acc_custom_cont_fld'] ) ) {
				update_post_meta( $post_id, 'kamy_acc_custom_cont_fld', sanitize_meta( '', wp_unslash( $_POST['kamy_acc_custom_cont_fld'] ), '' ) );
			}

			if ( isset( $_POST['kamy_acc_link_fld'] ) ) {
				update_post_meta( $post_id, 'kamy_acc_link_fld', sanitize_meta( '', wp_unslash( $_POST['kamy_acc_link_fld'] ), '' ) );
			}

			if ( isset( $_POST['kamy_acc_page_fld'] ) ) {
				update_post_meta( $post_id, 'kamy_acc_page_fld', sanitize_meta( '', wp_unslash( $_POST['kamy_acc_page_fld'] ), '' ) );
			}

			if ( isset( $_POST['kamy_acc_menu_title'] ) ) {
				update_post_meta( $post_id, 'kamy_acc_menu_title', sanitize_meta( '', wp_unslash( $_POST['kamy_acc_menu_title'] ), '' ) );
			}

			if ( isset( $_POST['kamy_acc_group_child'] ) ) {

				$child_array = sanitize_meta( '', wp_unslash( $_POST['kamy_acc_group_child'] ), '' );
				if ( is_array( $child_array ) ) {
					update_post_meta( $post_id, 'kamy_acc_group_child', wp_json_encode( $child_array ) );
				} else {
					update_post_meta( $post_id, 'kamy_acc_group_child', wp_json_encode( array() ) );
				}
			} else {
				update_post_meta( $post_id, 'kamy_acc_group_child', wp_json_encode( array() ) );
			}

			if ( isset( $_POST['kamy_acc_group_default_filed'] ) ) {

				$child_array = sanitize_meta( '', wp_unslash( $_POST['kamy_acc_group_default_filed'] ), '' );
				if ( is_array( $child_array ) ) {
					update_post_meta( $post_id, 'kamy_acc_group_default_filed', wp_json_encode( $child_array ) );
				} else {
					update_post_meta( $post_id, 'kamy_acc_group_default_filed', wp_json_encode( array() ) );
				}
			} else {
				update_post_meta( $post_id, 'kamy_acc_group_default_filed', wp_json_encode( array() ) );
			}
		}
	}

	new KA_MyAcc_Admin();

}